***
API
***

Code documentation of Pydoas API.
   
Data import
===========

.. automodule:: pydoas.dataimport
   :members:
   :undoc-members:
   
Fit result analysis and plotting
================================

.. automodule:: pydoas.analysis
   :members:
   :undoc-members:

Supplemental / IO / Helpers
===========================

.. automodule:: pydoas.inout
   :members:
   :undoc-members:
   
